PDS Deep Archive
===================

The PDS Deep Archive is a Python_ based package providing utilities for
handling *deep* archives. It includes software for Archive Information Package
(AIP) and Submission Information Package (SIP) products, based on Open
Archival Information System (OAIS_) standards.

Currently, this package provides three executable programs:

•  ``pds-deep-archive``, primary executable for creating both Archive Information Packages (AIPs) and Submission Information Packages (SIPs); and
•  ``aipgen``, a subcomponent of ``pds-deep-archive`` to create Archive Information Packages (AIPs); and
•  ``sipgen``, a subcomponent of ``pds-deep-archive`` to create Submission Information Packages (SIPs)

from PDS bundles.


.. toctree::
   :maxdepth: 2
   :caption: Contents:

   installation/index
   usage/index
   development/index


.. Perhaps we will use this in the future:
.. Indexes and Tables
.. ==================

.. • :ref:`genindex`
.. • :ref:`modindex`
.. • :ref:`search`

.. _OAIS: https://www2.archivists.org/groups/standards-committee/open-archival-information-system-oais
.. _Python: https://www.python.org/
